# fvGP

[![PyPI](https://img.shields.io/pypi/v/fvGP)](https://pypi.org/project/fvgp/)
[![Documentation Status](https://readthedocs.org/projects/gpcam/badge/?version=latest)](https://gpcam.readthedocs.io/en/latest/?badge=latest)
[![fvGP CI](https://github.com/lbl-camera/fvGP/actions/workflows/fvGP-CI.yml/badge.svg)](https://github.com/lbl-camera/fvGP/actions/workflows/fvGP-CI.yml)
[![Codecov](https://img.shields.io/codecov/c/github/lbl-camera/fvGP)](https://app.codecov.io/gh/lbl-camera/fvGP)
[![PyPI - License](https://img.shields.io/badge/license-GPL%20v3-lightgrey)](https://pypi.org/project/fvgp/)
[<img src="https://img.shields.io/badge/slack-@gpCAM-purple.svg?logo=slack">](https://gpCAM.slack.com/)
[![DOI](https://zenodo.org/badge/434769505.svg)](https://zenodo.org/badge/latestdoi/434769505)


Python package for highly flexible function-valued Gaussian processes (fvGP)

Specialties: Extreme-Scale GPs, GPs Tailored for HPC training, Advanced Kenrel Designs, Domain-Aware Stochastic Function Approximation
Coming soon: All those advancements for stochastic manifold learning

## Credits

This package uses the HGDL package of David Perryman and Marcus Noack, which
is based on the [HGDN](https://www.sciencedirect.com/science/article/pii/S037704271730225X) algorithm by Noack and Funke.
